import os
import unittest

from gi.repository import GObject
from gi.repository import WebKit
from gi.repository import Soup

from testutils import setup_test_env
setup_test_env()

from softwarecenter.ui.gtk3.views.webkit import LocaleAwareWebView

class WebkitTestCase(unittest.TestCase):

    def setUp(self):
        self.loop = GObject.MainLoop(GObject.main_context_default())
        # add log
        session = WebKit.get_default_session()
        logger = Soup.Logger.new(Soup.LoggerLogLevel.HEADERS, -1)
        logger.set_printer(self._soup_log_collector, None)
        logger.attach(session)
        self.addCleanup(lambda: logger.detach(session))
        self._soup_headers = []
 
    def test_webkit_oauth(self):
        oauth = { "token" : "aToken",
                  "consumer_key" : "aConsumerKey",
                  "consumer_secret" : "aConsumerSecret",
                  "token_secret" : "aTokenSecret",
                 }
        wk = LocaleAwareWebView(oauth_token=oauth)
        wk.connect("notify::load-status", self._on_load_status_changed)
        wk.open("https://software-center.ubuntu.com/subscriptions/en/ubuntu/precise/+new/?archive_id=commercial-ppa-uploaders%2Fworld-of-goo&arch=amd64")
        self.loop.run()
        # poor mans check
        for header in self._soup_headers:
            if "oauth_signature" in header:
                break
        else:
            raise Exception("Failed to find oauth_signature in headers")

    def _soup_log_collector(self, logger, level, direction, data, user_data):
        #print logger, level, direction, data
        self._soup_headers.append(data)

    def _on_load_status_changed(self, view, pspec):
        prop = pspec.name
        status = view.get_property(prop)
        if (status == WebKit.LoadStatus.FINISHED or
            status == WebKit.LoadStatus.FAILED):
            self.loop.quit()

if __name__ == "__main__":
    unittest.main()
